/******************************************************************************
* Copyright (C) 2023 - 2026 Advanced Micro Devices, Inc.  All rights reserved.
* SPDX-License-Identifier: MIT
******************************************************************************/
#ifndef _XFPGA_CONFIG_H
/** Header guard for xfpga_config.h */
#define _XFPGA_CONFIG_H

#include <xilfpga.h>
#include <xilfpga_pcap.h>
#include <xilfpga_pcap_common.h>


/** On-Chip Memory address */
#define XFPGA_OCM_ADDRESS	0xfffc0000U
/** Base address for FPGA operations */
#define XFPGA_BASE_ADDRESS	0x80000U
/** Enable secure mode */
#define XFPGA_SECURE_MODE	 
#define XFPGA_DEBUG	 0
/** Enable secure readback mode */
/* #undef XFPGA_SECURE_READBACK_MODE */
/** Enable secure IPI mode */
/* #undef XFPGA_SECURE_IPI_MODE_EN */
/** Read configuration register */
#define XFPGA_READ_CONFIG_REG  
/** Read configuration data */
#define XFPGA_READ_CONFIG_DATA  
/** Enable frame readback */
/* #undef XFPGA_FRAME_READBACK */
/** Get version information */
/* #undef XFPGA_GET_VERSION_INFO */
/** Get feature list */
/* #undef XFPGA_GET_FEATURE_LIST */
/** Skip eFUSE check */
/* #undef XFPGA_SKIP_EFUSE_CHECK */
#endif /* XFPGA_CONFIG_H */
